==> testcontainers-annotations-1.3.2-sources.jar: dev/vality/testcontainers/annotations/kafka/config/KafkaProducerConfig.java <==
package dev.vality.testcontainers.annotations.kafka.config;

import com.rbkmoney.kafka.common.serialization.ThriftSerializer;
import org.apache.kafka.clients.producer.ProducerConfig;
import org.apache.kafka.common.serialization.StringSerializer;
import org.apache.thrift.TBase;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.test.context.TestConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.kafka.core.DefaultKafkaProducerFactory;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.kafka.core.ProducerFactory;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * Конфиг для инциализации тестового продьюссера для тестирования трифтовых топиков
 *
 * @see KafkaProducer KafkaProducer
 */
@TestConfiguration
public class KafkaProducerConfig {

    @Value("${kafka.bootstrap-servers}")
    private String bootstrapAddress;

    @Bean
    public KafkaProducer<TBase<?, ?>> testThriftKafkaProducer() {
        return new KafkaProducer<>(new KafkaTemplate<>(thriftProducerFactory()));
    }

    private ProducerFactory<String, TBase<?, ?>> thriftProducerFactory() {
        Map<String, Object> props = new HashMap<>();
        props.put(ProducerConfig.BOOTSTRAP_SERVERS_CONFIG, bootstrapAddress);
        props.put(ProducerConfig.CLIENT_ID_CONFIG, UUID.randomUUID().toString());
        props.put(ProducerConfig.KEY_SERIALIZER_CLASS_CONFIG, StringSerializer.class.getName());
        props.put(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG, ThriftSerializer.class.getName());
        return new DefaultKafkaProducerFactory<>(props);
    }
}

==> testcontainers-annotations-1.3.4-sources.jar: dev/vality/testcontainers/annotations/kafka/config/KafkaProducerConfig.java <==
package dev.vality.testcontainers.annotations.kafka.config;

import dev.vality.kafka.common.serialization.ThriftSerializer;
import org.apache.kafka.clients.producer.ProducerConfig;
import org.apache.kafka.common.serialization.StringSerializer;
import org.apache.thrift.TBase;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.test.context.TestConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.kafka.core.DefaultKafkaProducerFactory;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.kafka.core.ProducerFactory;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

/**
 * Конфиг для инциализации тестового продьюссера для тестирования трифтовых топиков
 *
 * @see KafkaProducer KafkaProducer
 */
@TestConfiguration
public class KafkaProducerConfig {

    @Value("${kafka.bootstrap-servers}")
    private String bootstrapAddress;

    @Bean
    public KafkaProducer<TBase<?, ?>> testThriftKafkaProducer() {
        return new KafkaProducer<>(new KafkaTemplate<>(thriftProducerFactory()));
    }

    private ProducerFactory<String, TBase<?, ?>> thriftProducerFactory() {
        Map<String, Object> props = new HashMap<>();
        props.put(ProducerConfig.BOOTSTRAP_SERVERS_CONFIG, bootstrapAddress);
        props.put(ProducerConfig.CLIENT_ID_CONFIG, UUID.randomUUID().toString());
        props.put(ProducerConfig.KEY_SERIALIZER_CLASS_CONFIG, StringSerializer.class.getName());
        props.put(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG, ThriftSerializer.class.getName());
        return new DefaultKafkaProducerFactory<>(props);
    }
}
